@@ -140,7 +140,7 @@ class SessionTests(utils.TestCase):
                           session.get, self.TEST_URL)
 
     def test_session_debug_output(self):
-        """Test request and response headers in debug logs
+        """Test request and response headers in debug logs.
 
         in order to redact secure headers while debug is true.
         """
@@ -175,7 +175,7 @@ class SessionTests(utils.TestCase):
             self.assertNotIn(v, self.logger.output)
 
     def test_logs_failed_output(self):
-        """Test that output is logged even for failed requests"""
+        """Test that output is logged even for failed requests."""
         session = client_session.Session()
         body = uuid.uuid4().hex
 
@@ -717,6 +717,9 @@ class AdapterTest(utils.TestCase):
     REGION_NAME = uuid.uuid4().hex
     USER_AGENT = uuid.uuid4().hex
     VERSION = uuid.uuid4().hex
+    ALLOW = {'allow_deprecated': False,
+             'allow_experimental': True,
+             'allow_unknown': True}
 
     TEST_URL = CalledAuthPlugin.ENDPOINT
 
@@ -730,7 +733,8 @@ class AdapterTest(utils.TestCase):
                                interface=self.INTERFACE,
                                region_name=self.REGION_NAME,
                                user_agent=self.USER_AGENT,
-                               version=self.VERSION)
+                               version=self.VERSION,
+                               allow=self.ALLOW)
 
     def _verify_endpoint_called(self, adpt):
         self.assertEqual(self.SERVICE_TYPE,
@@ -752,6 +756,8 @@ class AdapterTest(utils.TestCase):
         self.assertEqual(resp.text, response)
 
         self._verify_endpoint_called(adpt)
+        self.assertEqual(self.ALLOW,
+                         adpt.auth.endpoint_arguments['allow'])
         self.assertTrue(adpt.auth.get_token_called)
         self.assertRequestHeaderEqual('User-Agent', self.USER_AGENT)
 
